Unified protocol server lifecycle implementation Unified protocol server implementation for the HTTP mock server.
Structs
- Http
Mock Server - A
MockProtocolServerwrapper around the HTTP server startup.
Unified protocol server lifecycle implementation Unified protocol server implementation for the HTTP mock server.
MockProtocolServer wrapper around the HTTP server startup.